pyrasite-gui - A graphical interface for Pyrasite
=================================================

The GUI has been moved into it's own repository:

https://github.com/lmacken/pyrasite-gui

.. image:: http://lewk.org/img/pyrasite/pyrasite-info.png

.. image:: http://lewk.org/img/pyrasite/pyrasite-stacks.png

.. image:: http://lewk.org/img/pyrasite/pyrasite-objects.png

.. image:: http://lewk.org/img/pyrasite/pyrasite-shell.png

.. image:: http://lewk.org/img/pyrasite/pyrasite-callgraph.png
